#ifndef __MDFN_PSX_INPUT_NEGCON_H
#define __MDFN_PSX_INPUT_NEGCON_H

namespace MDFN_IEN_PSX
{
 InputDevice *Device_neGcon_Create(void);
 extern IDIISG Device_neGcon_IDII;
}
#endif
